==> jc-1.4.0.tar.gz: polyglot/parse/VarDeclarator.h <==
// public class polyglot.parse.VarDeclarator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e329cd839509c30c polyglot_parse_VarDeclarator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_parse_VarDeclarator_H_
#define _JC_polyglot_parse_VarDeclarator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_parse_VarDeclarator$sub_refs	_jc_polyglot_parse_VarDeclarator$sub_refs;
typedef struct _jc_polyglot_parse_VarDeclarator$sub_nonrefs	_jc_polyglot_parse_VarDeclarator$sub_nonrefs;
typedef struct _jc_polyglot_parse_VarDeclarator$refs	_jc_polyglot_parse_VarDeclarator$refs;
typedef struct _jc_polyglot_parse_VarDeclarator$nonrefs	_jc_polyglot_parse_VarDeclarator$nonrefs;
typedef struct _jc_polyglot_parse_VarDeclarator$object	_jc_polyglot_parse_VarDeclarator$object;

typedef const struct _jc_polyglot_parse_VarDeclarator$vmethods	_jc_polyglot_parse_VarDeclarator$vmethods;
typedef const struct _jc_polyglot_parse_VarDeclarator$vtable	_jc_polyglot_parse_VarDeclarator$vtable;
typedef const struct _jc_polyglot_parse_VarDeclarator$vtype	_jc_polyglot_parse_VarDeclarator$vtype;

// Constructors
extern void _jc_polyglot_parse_VarDeclarator$method$_init$e1025501fac123ee(_jc_env *, struct _jc_polyglot_parse_VarDeclarator$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c(_jc_env *, struct _jc_polyglot_parse_VarDeclarator$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_parse_VarDeclarator$method_info$position$bb89333b1e4c840c;

// Virtual methods structure
struct _jc_polyglot_parse_VarDeclarator$vmethods {
	struct _jc_polyglot_util_Position$object	*(*position$bb89333b1e4c840c)(_jc_env *, struct _jc_polyglot_parse_VarDeclarator$object *);
};

// Vtable
struct _jc_polyglot_parse_VarDeclarator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_parse_VarDeclarator$vmethods	polyglot_parse_VarDeclarator;
};

// Vtype
struct _jc_polyglot_parse_VarDeclarator$vtype {
	_jc_type			type;
	_jc_polyglot_parse_VarDeclarator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_parse_VarDeclarator$sub_refs {
	struct _jc_polyglot_util_Position$object	*pos;
	struct _jc_java_lang_String$object	*name;
	struct _jc_object	*init;
};

// Reference instance fields (object)
struct _jc_polyglot_parse_VarDeclarator$refs {
    _jc_polyglot_parse_VarDeclarator$sub_refs	polyglot_parse_VarDeclarator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_parse_VarDeclarator$sub_nonrefs {
	jint	dims;
};

// Non-reference instance fields (object)
struct _jc_polyglot_parse_VarDeclarator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_parse_VarDeclarator$sub_nonrefs	polyglot_parse_VarDeclarator;
};

// Object instance structure
struct _jc_polyglot_parse_VarDeclarator$object {
	_jc_polyglot_parse_VarDeclarator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_parse_VarDeclarator$vtype	*vtype;
	_jc_polyglot_parse_VarDeclarator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_parse_VarDeclarator$vtype _jc_polyglot_parse_VarDeclarator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_parse_VarDeclarator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_parse_VarDeclarator$class_object;

#endif	/* _JC_polyglot_parse_VarDeclarator_H_ */

==> jc-1.4.6.tar.gz: polyglot/parse/VarDeclarator.h <==
// public class polyglot.parse.VarDeclarator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e329cd839509c30c polyglot_parse_VarDeclarator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_parse_VarDeclarator_H_
#define _JC_polyglot_parse_VarDeclarator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_parse_VarDeclarator$sub_refs	_jc_polyglot_parse_VarDeclarator$sub_refs;
typedef struct _jc_polyglot_parse_VarDeclarator$sub_nonrefs	_jc_polyglot_parse_VarDeclarator$sub_nonrefs;
typedef struct _jc_polyglot_parse_VarDeclarator$refs	_jc_polyglot_parse_VarDeclarator$refs;
typedef struct _jc_polyglot_parse_VarDeclarator$nonrefs	_jc_polyglot_parse_VarDeclarator$nonrefs;
typedef struct _jc_polyglot_parse_VarDeclarator$object	_jc_polyglot_parse_VarDeclarator$object;

typedef const struct _jc_polyglot_parse_VarDeclarator$vmethods	_jc_polyglot_parse_VarDeclarator$vmethods;
typedef const struct _jc_polyglot_parse_VarDeclarator$vtable	_jc_polyglot_parse_VarDeclarator$vtable;
typedef const struct _jc_polyglot_parse_VarDeclarator$vtype	_jc_polyglot_parse_VarDeclarator$vtype;

// Constructors
extern void _jc_polyglot_parse_VarDeclarator$method$_init$e1025501fac123ee(_jc_env *, struct _jc_polyglot_parse_VarDeclarator$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_parse_VarDeclarator$method$position$bb89333b1e4c840c(_jc_env *, struct _jc_polyglot_parse_VarDeclarator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_parse_VarDeclarator$method_info$position$bb89333b1e4c840c;

// Virtual methods structure
struct _jc_polyglot_parse_VarDeclarator$vmethods {
	struct _jc_polyglot_util_Position$object	*(*position$bb89333b1e4c840c)(_jc_env *, struct _jc_polyglot_parse_VarDeclarator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_parse_VarDeclarator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_parse_VarDeclarator$vmethods	polyglot_parse_VarDeclarator;
};

// Vtype
struct _jc_polyglot_parse_VarDeclarator$vtype {
	_jc_type			type;
	_jc_polyglot_parse_VarDeclarator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_parse_VarDeclarator$sub_refs {
	struct _jc_polyglot_util_Position$object	*pos;
	struct _jc_java_lang_String$object	*name;
	struct _jc_object	*init;
};

// Reference instance fields (object)
struct _jc_polyglot_parse_VarDeclarator$refs {
    _jc_polyglot_parse_VarDeclarator$sub_refs	polyglot_parse_VarDeclarator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_parse_VarDeclarator$sub_nonrefs {
	jint	dims;
};

// Non-reference instance fields (object)
struct _jc_polyglot_parse_VarDeclarator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_parse_VarDeclarator$sub_nonrefs	polyglot_parse_VarDeclarator;
};

// Object instance structure
struct _jc_polyglot_parse_VarDeclarator$object {
	_jc_polyglot_parse_VarDeclarator$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_parse_VarDeclarator$vtype	*vtype;
	_jc_polyglot_parse_VarDeclarator$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_parse_VarDeclarator$vtype _jc_polyglot_parse_VarDeclarator$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_parse_VarDeclarator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_parse_VarDeclarator$class_object;

#endif	/* _JC_polyglot_parse_VarDeclarator_H_ */
